<?php
/**
 * Visual Composer List Item
 *
 * @package Total WordPress Theme
 * @subpackage VC Functions
 * @version 3.3.0
 */

/**
 * Register shortcode with VC Composer
 *
 * @since 2.0.0
 */
class WPBakeryShortCode_vcex_list_item extends WPBakeryShortCode {
	protected function content( $atts, $content = null ) {
		ob_start();
		include( locate_template( 'vcex_templates/vcex_list_item.php' ) );
		return ob_get_clean();
	}
}

/**
 * Adds the shortcode to the Visual Composer
 *
 * @since 1.4.1
 */
function vcex_list_item_vc_map() {
	return array(
		'name' => esc_html__( 'List Item', 'total' ),
		'description' => esc_html__( 'Font Icon list item', 'total' ),
		'base' => 'vcex_list_item',
		'icon' => 'vcex-list-item vcex-icon fa fa-list',
		'category' => wpex_get_theme_branding(),
		'params' => array(
			// General
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Unique Id', 'total' ),
				'param_name' => 'unique_id',
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Custom Classes', 'total' ),
				'param_name' => 'classes',
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Visibility', 'total' ),
				'param_name' => 'visibility',
				'value' => array_flip( wpex_visibility() ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Appear Animation', 'total' ),
				'param_name' => 'css_animation',
				'value' => array_flip( wpex_css_animations() ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Content', 'total' ),
				'param_name' => 'content',
				'admin_label' => true,
				'value' => esc_html__( 'This is a pretty list item', 'total' ),
			),
			array(
				'type'  => 'vcex_font_family_select',
				'heading'  => esc_html__( 'Font Family', 'total' ),
				'param_name'  => 'font_family',
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Font Size', 'total' ),
				'param_name' => 'font_size',
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Text Align', 'total' ),
				'param_name' => 'text_align',
				'value' => array_flip( wpex_alignments() ),
			),
			array(
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Color', 'total' ),
				'param_name' => 'font_color',
			),
			// Icon
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Icon library', 'total' ),
				'param_name' => 'icon_type',
				'description' => esc_html__( 'Select icon library.', 'total' ),
				'value' => array(
					__( 'Font Awesome', 'total' ) => 'fontawesome',
					__( 'Open Iconic', 'total' ) => 'openiconic',
					__( 'Typicons', 'total' ) => 'typicons',
					__( 'Entypo', 'total' ) => 'entypo',
					__( 'Linecons', 'total' ) => 'linecons',
					__( 'Pixel', 'total' ) => 'pixelicons',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'iconpicker',
				'heading' => esc_html__( 'Icon', 'total' ),
				'param_name' => 'icon',
				'value' => 'fa fa-info-circle',
				'settings' => array(
					'emptyIcon' => true,
					'iconsPerPage' => 200,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value' => 'fontawesome',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'iconpicker',
				'heading' => esc_html__( 'Icon', 'total' ),
				'param_name' => 'icon_openiconic',
				'settings' => array(
					'emptyIcon' => true,
					'type' => 'openiconic',
					'iconsPerPage' => 200,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value' => 'openiconic',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'iconpicker',
				'heading' => esc_html__( 'Icon', 'total' ),
				'param_name' => 'icon_typicons',
				'settings' => array(
					'emptyIcon' => true,
					'type' => 'typicons',
					'iconsPerPage' => 200,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value' => 'typicons',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'iconpicker',
				'heading' => esc_html__( 'Icon', 'total' ),
				'param_name' => 'icon_entypo',
				'settings' => array(
					'emptyIcon' => true,
					'type' => 'entypo',
					'iconsPerPage' => 300,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value' => 'entypo',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'iconpicker',
				'heading' => esc_html__( 'Icon', 'total' ),
				'param_name' => 'icon_linecons',
				'settings' => array(
					'emptyIcon' => true,
					'type' => 'linecons',
					'iconsPerPage' => 200,
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value' => 'linecons',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'iconpicker',
				'heading' => esc_html__( 'Icon', 'total' ),
				'param_name' => 'icon_pixelicons',
				'settings' => array(
					'emptyIcon' => true,
					'type' => 'pixelicons',
					'source' => vcex_pixel_icons(),
				),
				'dependency' => array(
					'element' => 'icon_type',
					'value' => 'pixelicons',
				),
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Right Margin', 'total' ),
				'param_name' => 'margin_right',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Color', 'total' ),
				'param_name' => 'color',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Background', 'total' ),
				'param_name' => 'icon_background',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Size', 'total' ),
				'param_name' => 'icon_size',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Border Radius', 'total' ),
				'param_name' => 'icon_border_radius',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Width', 'total' ),
				'param_name' => 'icon_width',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Height', 'total' ),
				'param_name' => 'icon_height',
				'group' => esc_html__( 'Icon', 'total' ),
			),
			// Link
			array(
				'type' => 'vc_link',
				'heading' => esc_html__( 'Link', 'total' ),
				'param_name' => 'link',
				'group' => esc_html__( 'Link', 'total' ),
			),
			// CSS
			array(
				'type' => 'css_editor',
				'heading' => esc_html__( 'CSS', 'total' ),
				'param_name' => 'css',
				'description' => esc_html__( 'If any of these are defined it will add a new wrapper around your icon box with the custom CSS applied to it.', 'total' ),
				'group' => esc_html__( 'Design', 'total' ),
			),

		)
	);
}
vc_lean_map( 'vcex_list_item', 'vcex_list_item_vc_map' );