<?php
/**
 * Visual Composer Post Type Carousel
 *
 * @package Total WordPress Theme
 * @subpackage VC Functions
 * @version 3.3.5
 */

/**
 * Register shortcode with VC Composer
 *
 * @since 2.0.0
 */
class WPBakeryShortCode_vcex_post_type_carousel extends WPBakeryShortCode {
	protected function content( $atts, $content = null ) {
		ob_start();
		include( locate_template( 'vcex_templates/vcex_post_type_carousel.php' ) );
		return ob_get_clean();
	}
}

/**
 * Adds the shortcode to the Visual Composer
 *
 * @since 1.4.1
 */
function vcex_post_type_carousel_map() {

	// Strings
	$s_enable = esc_html__( 'Enable', 'total' );
	$s_yes    = esc_html__( 'Yes', 'total' );
	$s_no     = esc_html__( 'No', 'total' );

	// Return array
	return array(
		'name' => esc_html__( 'Post Types Carousel', 'total' ),
		'description' => esc_html__( 'Posts carousel', 'total' ),
		'base' => 'vcex_post_type_carousel',
		'category' => wpex_get_theme_branding(),
		'icon' => 'vcex-post-type-carousel vcex-icon fa fa-files-o',
		'params' => array(
			// General
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Unique Id', 'total' ),
				'param_name' => 'unique_id',
				'admin_label' => true,
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Custom Classes', 'total' ),
				'param_name' => 'classes',
				'admin_label' => true,
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Visibility', 'total' ),
				'param_name' => 'visibility',
				'value' => array_flip( wpex_visibility() ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Appear Animation', 'total'),
				'param_name' => 'css_animation',
				'value' => array_flip( wpex_css_animations() ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Style', 'total' ),
				'param_name' => 'style',
				'value' => array(
					__( 'Default', 'total') => 'default',
					__( 'No Margins', 'total' ) => 'no-margins',
				),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Arrows?', 'total' ),
				'param_name' => 'arrows',
				'value' => array( $s_yes => 'true', $s_no => 'false' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Dots?', 'total' ),
				'param_name' => 'dots',
				'value' => array( $s_no => 'false', $s_yes => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Items To Display', 'total' ),
				'param_name' => 'items',
				'value' => '4',
				'admin_label' => true,
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Items To Scrollby', 'total' ),
				'param_name' => 'items_scroll',
				'value' => '1',
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Margin Between Items', 'total' ),
				'param_name' => 'items_margin',
				'value' => '15',
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Auto Play', 'total' ),
				'param_name' => 'auto_play',
				'value' => array( $s_no => 'false', $s_yes => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Timeout Duration in milliseconds', 'total' ),
				'param_name' => 'timeout_duration',
				'value' => '5000',
				'dependency' => array( 'element' => 'auto_play', 'value' => 'true' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Infinite Loop', 'total' ),
				'param_name' => 'infinite_loop',
				'value' => array( $s_yes => 'true', $s_no => 'false' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Center Item', 'total' ),
				'param_name' => 'center',
				'value' => array( $s_no => 'false', $s_yes => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Animation Speed', 'total' ),
				'param_name' => 'animation_speed',
				'value' => '150',
				'description' => esc_html__( 'Default is 150 milliseconds. Enter 0.0 to disable.', 'total' ),
			),
			// Query
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Post Count', 'total' ),
				'param_name' => 'count',
				'value' => '8',
				'group' => esc_html__( 'Query', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Offset', 'total' ),
				'param_name' => 'offset',
				'group' => esc_html__( 'Query', 'total' ),
				'description' => esc_html__( 'Number of post to displace or pass over. Warning: Setting the offset parameter overrides/ignores the paged parameter and breaks pagination. The offset parameter is ignored when posts per page is set to -1.', 'total' ),
			),
			array(
				'type' => 'posttypes',
				'heading' => esc_html__( 'Post types', 'total' ),
				'param_name' => 'post_types',
				'std' => 'post',
				'group' => esc_html__( 'Query', 'total' ),
				'admin_label' => true,
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Limit By Post ID\'s', 'total' ),
				'param_name' => 'posts_in',
				'group' => esc_html__( 'Query', 'total' ),
				'description' => esc_html__( 'Seperate by a comma.', 'total' ),
			),
			array(
				'type' => 'autocomplete',
				'heading' => esc_html__( 'Limit By Author', 'total' ),
				'param_name' => 'author_in',
				'settings' => array(
					'multiple' => true,
					'min_length' => 1,
					'groups' => false,
					'unique_values' => true,
					'display_inline' => true,
					'delay' => 0,
					'auto_focus' => true,
				),
				'group' => esc_html__( 'Query', 'total' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Query by Taxonomy', 'total' ),
				'param_name' => 'tax_query',
				'value' => array(
					__( 'No', 'total' ) => 'false',
					__( 'Yes', 'total') => 'true',
				),
				'group' => esc_html__( 'Query', 'total' ),
			),
			array(
				'type' => 'autocomplete',
				'heading' => esc_html__( 'Taxonomy Name', 'total' ),
				'param_name' => 'tax_query_taxonomy',
				'dependency' => array(
					'element' => 'tax_query',
					'value' => 'true',
				),
				'settings' => array(
					'multiple' => false,
					'min_length' => 1,
					'groups' => false,
					'display_inline' => true,
					'delay' => 0,
					'auto_focus' => true,
				),
				'group' => esc_html__( 'Query', 'total' ),
				'description' => esc_html__( 'If you do not see your taxonomy in the dropdown you can still enter the taxonomy name manually.', 'total' ),
			),
			array(
				'type' => 'autocomplete',
				'heading' => esc_html__( 'Terms', 'total' ),
				'param_name' => 'tax_query_terms',
				'dependency' => array( 'element' => 'tax_query', 'value' => 'true' ),
				'settings' => array(
					'multiple' => true,
					'min_length' => 1,
					'groups' => true,
					'display_inline' => true,
					'delay' => 0,
					'auto_focus' => true,
				),
				'group' => esc_html__( 'Query', 'total' ),
				'description' => esc_html__( 'If you do not see your terms in the dropdown you can still enter the term slugs manually seperated by a space.', 'total' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Ignore Sticky Posts', 'total' ),
				'param_name' => 'ignore_sticky_posts',
				'value' => array(
					$s_no => '',
					$s_yes => 'true',
				),
				'group' => esc_html__( 'Query', 'total' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Order', 'total' ),
				'param_name' => 'order',
				'group' => esc_html__( 'Query', 'total' ),
				'value' => array(
					__( 'Default', 'total' ) => 'default',
					__( 'DESC', 'total' ) => 'DESC',
					__( 'ASC', 'total' ) => 'ASC',
				),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Order By', 'total' ),
				'param_name' => 'orderby',
				'value' => vcex_orderby_array(),
				'group' => esc_html__( 'Query', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Orderby: Meta Key', 'total' ),
				'param_name' => 'orderby_meta_key',
				'group' => esc_html__( 'Query', 'total' ),
				'dependency' => array( 'element' => 'orderby', 'value' => array( 'meta_value_num', 'meta_value' ) ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Post With Thumbnails Only', 'total' ),
				'param_name' => 'thumbnail_query',
				'value' => array(
					__( 'No', 'total' ) => 'false',
					__( 'Yes', 'total') => 'true',
				),
				'group' => esc_html__( 'Query', 'total' ),
			),
			// Image
			array(
				'type' => 'dropdown',
				'heading' => $s_enable,
				'param_name' => 'media',
				'value' => array(
					$s_yes => 'true',
					$s_no => 'false',
				),
				'group' => esc_html__( 'Image', 'total' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Image Links To', 'total' ),
				'param_name' => 'thumbnail_link',
				'value' => array(
					esc_html__( 'Default', 'total') => '',
					esc_html__( 'Post', 'total') => 'post',
					esc_html__( 'Lightbox', 'total' ) => 'lightbox',
					esc_html__( 'None', 'total' ) => 'none',
				),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'media', 'value' => 'true' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Image Size', 'total' ),
				'param_name' => 'img_size',
				'std' => 'full',
				'value' => vcex_image_sizes(),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'media', 'value' => 'true' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Image Crop Location', 'total' ),
				'param_name' => 'img_crop',
				'std' => 'center-center',
				'value' => array_flip( wpex_image_crop_locations() ),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'img_size', 'value' => 'wpex_custom', ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Image Crop Width', 'total' ),
				'param_name' => 'img_width',
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'img_size', 'value' => 'wpex_custom', ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Image Crop Height', 'total' ),
				'param_name' => 'img_height',
				'description' => esc_html__( 'Enter a height in pixels. Leave empty to disable vertical cropping and keep image proportions.', 'total' ),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'img_size', 'value' => 'wpex_custom', ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Image Overlay', 'total' ),
				'param_name' => 'overlay_style',
				'value' => array_flip( wpex_overlay_styles_array() ),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'media', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Overlay Button Text', 'total' ),
				'param_name' => 'overlay_button_text',
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'overlay_style', 'value' => 'hover-button' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Overlay Excerpt Length', 'total' ),
				'param_name' => 'overlay_excerpt_length',
				'value' => '15',
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'overlay_style', 'value' => 'title-excerpt-hover' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Image Hover', 'total' ),
				'param_name' => 'img_hover_style',
				'value' => array_flip( wpex_image_hovers() ),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'media', 'value' => 'true' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Image Filter', 'total' ),
				'param_name' => 'img_filter',
				'value' => array_flip( wpex_image_filters() ),
				'group' => esc_html__( 'Image', 'total' ),
				'dependency' => array( 'element' => 'media', 'value' => 'true' ),
			),
			// Title
			array(
				'type' => 'dropdown',
				'heading' => $s_enable,
				'param_name' => 'title',
				'value' => array(
					$s_yes => 'true',
					$s_no => 'false',
				),
				'group' => esc_html__( 'Title', 'total' ),
			),
			array(
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Color', 'total' ),
				'param_name' => 'content_heading_color',
				'group' => esc_html__( 'Title', 'total' ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Font Size', 'total' ),
				'param_name' => 'content_heading_size',
				'group' => esc_html__( 'Title', 'total' ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Margin', 'total' ),
				'param_name' => 'content_heading_margin',
				'description' => esc_html__( 'Please use the following format: top right bottom left.', 'total' ),
				'group' => esc_html__( 'Title', 'total' ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Line Height', 'total' ),
				'param_name' => 'content_heading_line_height',
				'group' => esc_html__( 'Title', 'total' ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Font Weight', 'total' ),
				'param_name' => 'content_heading_weight',
				'group' => esc_html__( 'Title', 'total' ),
				'std' => '',
				'value' => array_flip( wpex_font_weights() ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Text Transform', 'total' ),
				'param_name' => 'content_heading_transform',
				'value' => array_flip( wpex_text_transforms() ),
				'group' => esc_html__( 'Title', 'total' ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),
			// Date
			array(
				'type' => 'dropdown',
				'heading' => $s_enable,
				'param_name' => 'date',
				'value' => array(
					$s_yes => 'true',
					$s_no => 'false',
				),
				'group' => esc_html__( 'Date', 'total' ),
			),
			array(
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Color', 'total' ),
				'param_name' => 'date_color',
				'group' => esc_html__( 'Date', 'total' ),
				'dependency' => array( 'element' => 'date', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Font Size', 'total' ),
				'param_name' => 'date_font_size',
				'group' => esc_html__( 'Date', 'total' ),
				'dependency' => array( 'element' => 'date', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Margin', 'total' ),
				'param_name' => 'date_margin',
				'description' => esc_html__( 'Please use the following format: top right bottom left.', 'total' ),
				'group' => esc_html__( 'Date', 'total' ),
				'dependency' => array( 'element' => 'title', 'value' => 'true' ),
			),

			// Excerpt
			array(
				'type' => 'dropdown',
				'heading' => $s_enable,
				'param_name' => 'excerpt',
				'value' => array(
					$s_yes => 'true',
					$s_no => 'false',
				),
				'group' => esc_html__( 'Excerpt', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Length', 'total' ),
				'param_name' => 'excerpt_length',
				'value' => '15',
				'description' => esc_html__( 'Enter how many words to display for the excerpt. To display the full post content enter "-1". To display the full post content up to the "more" tag enter "9999".', 'total' ),
				'group' => esc_html__( 'Excerpt', 'total' ),
				'dependency' => array( 'element' => 'excerpt', 'value' => 'true' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Font Size', 'total' ),
				'param_name' => 'content_font_size',
				'group' => esc_html__( 'Excerpt', 'total' ),
				'dependency' => array( 'element' => 'excerpt', 'value' => 'true' ),
			),
			array(
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Text Color', 'total' ),
				'param_name' => 'content_color',
				'group' => esc_html__( 'Excerpt', 'total' ),
				'dependency' => array( 'element' => 'excerpt', 'value' => 'true' ),
			),
			// Mobile
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Tablet: Items To Display', 'total' ),
				'param_name' => 'tablet_items',
				'value' => '3',
				'group' => esc_html__( 'Mobile', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Mobile Landscape: Items To Display', 'total' ),
				'param_name' => 'mobile_landscape_items',
				'value' => '2',
				'group' => esc_html__( 'Mobile', 'total' ),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Mobile Portrait: Items To Display', 'total' ),
				'param_name' => 'mobile_portrait_items',
				'value' => '1',
				'group' => esc_html__( 'Mobile', 'total' ),
			),
			// Content CSS
			array(
				'type' => 'css_editor',
				'heading' => esc_html__( 'Content CSS', 'total' ),
				'param_name' => 'content_css',
				'group' => esc_html__( 'Content CSS', 'total' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Content Alignment', 'total' ),
				'param_name' => 'content_alignment',
				'value' => array(
					__( 'Default', 'total' ) => '',
					__( 'Left', 'total' ) => 'left',
					__( 'Right', 'total' ) => 'right',
					__( 'Center', 'total' ) => 'center',
				),
				'group' => esc_html__( 'Content CSS', 'total' ),
			),
			// Entry CSS
			array(
				'type' => 'css_editor',
				'heading' => esc_html__( 'Entry CSS', 'total' ),
				'param_name' => 'entry_css',
				'group' => esc_html__( 'Entry CSS', 'total' ),
			),
		),
	);
}
vc_lean_map( 'vcex_post_type_carousel', 'vcex_post_type_carousel_map' );

// Get autocomplete suggestion
add_filter( 'vc_autocomplete_vcex_post_type_carousel_tax_query_taxonomy_callback', 'vcex_suggest_taxonomies', 10, 1 );
add_filter( 'vc_autocomplete_vcex_post_type_carousel_filter_taxonomy_callback', 'vcex_suggest_taxonomies', 10, 1 );
add_filter( 'vc_autocomplete_vcex_post_type_carousel_tax_query_terms_callback', 'vcex_suggest_terms', 10, 1 );
add_filter( 'vc_autocomplete_vcex_post_type_carousel_author_in_callback', 'vcex_suggest_users', 10, 1 );

// Render autocomplete suggestions
add_filter( 'vc_autocomplete_vcex_post_type_carousel_filter_taxonomy_render', 'vcex_render_taxonomies', 10, 1 );
add_filter( 'vc_autocomplete_vcex_post_type_carousel_tax_query_taxonomy_render', 'vcex_render_taxonomies', 10, 1 );
add_filter( 'vc_autocomplete_vcex_post_type_carousel_tax_query_terms_render', 'vcex_render_terms', 10, 1 );
add_filter( 'vc_autocomplete_vcex_post_type_carousel_author_in_render', 'vcex_render_users', 10, 1 );